Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrNoDelivery = errors.New("no delivery mechanisms configured")
ErrNoDelivery is returned when there's insufficient configuration for notification delivery.
Functions ¶
This section is empty.
Types ¶
type Mock ¶
type Mock struct {
Notifications_ func(ctx context.Context, id uuid.UUID, page *notifier.Page) ([]notifier.Notification, notifier.Page, error)
DeleteNotifications_ func(ctx context.Context, id uuid.UUID) error
}
Mock implements a mock notifier service
func (*Mock) DeleteNotifications ¶
type Notifier ¶ added in v4.4.0
type Notifier struct {
// contains filtered or unexported fields
}
Notifier is a local implementation of a notifier service.
func New ¶
func New(ctx context.Context, store notifier.Store, locks notifier.Locker, opts Opts) (*Notifier, error)
New returns a configured notifier subsystem.
func (*Notifier) DeleteNotifications ¶ added in v4.4.0
DeleteNotifications implements notifier.Service.
type Opts ¶
type Opts struct {
Matcher matcher.Service
Indexer indexer.Service
Signer webhook.Signer
Client *http.Client
Webhook *config.Webhook
AMQP *config.AMQP
STOMP *config.STOMP
PollInterval time.Duration
DeliveryInterval time.Duration
DisableSummary bool
}
Opts configures the notifier service.
Notes ¶
Bugs ¶
Currently only one delivery mechanism can be configured at a time.
The garbage collection period is currently unconfigurable.
Click to show internal directories.
Click to hide internal directories.